@@ -36,12 +36,13 @@ class KeycloakUser(BaseModel):
         email (Optional[str]):
         disableableCredentialTypes (List[str]):
         requiredActions (List[str]):
+        realmRoles (List[str]):
         notBefore (int):
         access (dict):
         attributes (Optional[dict]):
 
-    Notes:
-         Check the Keycloak documentation at https://www.keycloak.org/docs-api/15.0/rest-api/index.html for details. This is a mere proxy object.
+    Notes: Check the Keycloak documentation at https://www.keycloak.org/docs-api/15.0/rest-api/index.html for
+    details. This is a mere proxy object.
     """
     id: str
     createdTimestamp: int
@@ -54,6 +55,7 @@ class KeycloakUser(BaseModel):
     email: Optional[str]
     disableableCredentialTypes: List[str]
     requiredActions: List[str]
+    realmRoles: Optional[List[str]]
     notBefore: int
     access: dict
     attributes: Optional[dict]
@@ -71,7 +73,7 @@ class UsernamePassword(BaseModel):
 
 
 class OIDCUser(BaseModel):
-    """ Represents a user object of Keycloak, parsed from an access token 
+    """ Represents a user object of Keycloak, parsed from access token
     
     Attributes:
         sub (str):
@@ -85,9 +87,10 @@ class OIDCUser(BaseModel):
         email (Optional[str]):
         preferred_username (Optional[str]):
         realm_access (dict):
+        resource_access (dict):
 
-    Notes:
-         Check the Keycloak documentation at https://www.keycloak.org/docs-api/15.0/rest-api/index.html for details. This is a mere proxy object.
+    Notes: Check the Keycloak documentation at https://www.keycloak.org/docs-api/15.0/rest-api/index.html for
+    details. This is a mere proxy object.
     """
     sub: str
     iat: int
@@ -100,6 +103,7 @@ class OIDCUser(BaseModel):
     email: Optional[str]
     preferred_username: Optional[str]
     realm_access: Optional[dict]
+    resource_access: Optional[dict]
 
     @property
     def roles(self) -> List[str]:
@@ -110,8 +114,11 @@ class OIDCUser(BaseModel):
         """
         try:
             return self.realm_access['roles']
-        except KeyError:
-            raise KeycloakError(status_code=404, reason="The 'realm_access' section of the provided access token did not contain any 'roles'")
+        except KeyError as e:
+            raise KeycloakError(
+                status_code=404,
+                reason="The 'realm_access' section of the provided access token did not contain any 'roles'",
+            ) from e
 
     def __str__(self) -> str:
         """ String representation of an OIDCUser """
@@ -135,8 +142,8 @@ class KeycloakIdentityProvider(BaseModel):
         firstBrokerLoginFlowAlias (str):
         config (dict):
 
-    Notes:
-        Check the Keycloak documentation at https://www.keycloak.org/docs-api/15.0/rest-api/index.html for details. This is a mere proxy object.
+    Notes: Check the Keycloak documentation at https://www.keycloak.org/docs-api/15.0/rest-api/index.html for
+    details. This is a mere proxy object.
     """
     alias: str
     internalId: str
@@ -162,8 +169,8 @@ class KeycloakRole(BaseModel):
         clientRole (bool):
         containerId (str):
         
-    Notes:
-        Check the Keycloak documentation at https://www.keycloak.org/docs-api/15.0/rest-api/index.html for details. This is a mere proxy object.
+    Notes: Check the Keycloak documentation at https://www.keycloak.org/docs-api/15.0/rest-api/index.html for
+    details. This is a mere proxy object.
     """
     id: str
     name: str
